pub struct EmbeddingGenerator {
pub skip_existing: bool,
/* private fields */
}Expand description
Embedding generator using sentence-transformers.
Fields
skip_existing: boolIf true, skip entities that already have real (non-zero) embeddings.
Implementations
Sourceimpl EmbeddingGenerator
impl EmbeddingGenerator
Sourcepub fn with_config(config: EmbeddingConfig) -> Self
pub fn with_config(config: EmbeddingConfig) -> Self
Create a new embedding generator with custom configuration.
Sourcepub fn with_force(self, force: bool) -> Self
pub fn with_force(self, force: bool) -> Self
Set force mode: if true, regenerate embeddings even for entities that already have real (non-zero) vectors.
Sourcepub fn generate_embeddings(&self, texts: Vec<String>) -> Result<Vec<Vec<f32>>>
pub fn generate_embeddings(&self, texts: Vec<String>) -> Result<Vec<Vec<f32>>>
Generate embeddings for a list of texts.
Sourcepub fn generate_for_papers(&self, conn: &Connection) -> Result<EmbeddingStats>
pub fn generate_for_papers(&self, conn: &Connection) -> Result<EmbeddingStats>
Generate embeddings for all paper entities in the database.
Sourcepub fn generate_for_skills(&self, conn: &Connection) -> Result<EmbeddingStats>
pub fn generate_for_skills(&self, conn: &Connection) -> Result<EmbeddingStats>
Generate embeddings for all skill entities in the database.
Sourcepub fn generate_for_all(&self, conn: &Connection) -> Result<EmbeddingStats>
pub fn generate_for_all(&self, conn: &Connection) -> Result<EmbeddingStats>
Generate embeddings for all entities in the database.