pub fn schema_version(conn: &Connection) -> Result<Option<i32>>Expand description
Return the current schema version stored in the database.
Returns None if kg_schema_version has not been populated yet (e.g. a
legacy DB that has never been opened with this library version).