Module snapshot

Module snapshot 

Version snapshot operations — add/remove entities and relations to/from versions.

Functions

version_add_entity
Add an entity to a version (set the bit in its validity bitstring).
version_add_relation
Add a relation to a version.
version_remove_entity
Remove an entity from a version (clear the bit). If result is 0, set to NULL.
version_remove_relation
Remove a relation from a version. If result is 0, set to NULL.
version_snapshot_entities
Bulk add all entities to a version in a single operation.
version_snapshot_relations
Bulk add all relations to a version in a single operation.