Version snapshot operations — add/remove entities and relations to/from versions.
Functions
- version_
add_ entity - Add an entity to a version (set the bit in its validity bitstring).
- version_
add_ relation - Add a relation to a version.
- version_
remove_ entity - Remove an entity from a version (clear the bit). If result is 0, set to NULL.
- version_
remove_ relation - Remove a relation from a version. If result is 0, set to NULL.
- version_
snapshot_ entities - Bulk add all entities to a version in a single operation.
- version_
snapshot_ relations - Bulk add all relations to a version in a single operation.